import os
from mkdocs.plugins import BasePlugin
from mkdocs.structure.files import File

BASE_PATH = os.path.dirname(os.path.realpath(__file__))
BUNDLE_PATH = BASE_PATH + '/lib/'


class LogicBundlePlugin(BasePlugin):

    def __init__(self, **kwargs):
        super().__init__()

    def on_files(self, files, config):
        files.append(File('bundle.js', BUNDLE_PATH,
                          config['site_dir'] + '/javascripts/', False))
        files.append(File('bundle.js.map', BUNDLE_PATH,
                          config['site_dir'] + '/javascripts/', False))
        return files

    def on_post_page(self, out, page, config, **kwargs):
        out = out.replace("</title>",
                          f"</title>\n<script src=\"/javascripts/bundle.js\"></script>\n"
        )
        return out



import re

def formatter(source, language, css_class, options, md, classes, id_value, attrs=None, **kwargs):
    opt=''
    # Set default height to 150px if not provided in options
    if "height" not in options.keys():
        opt+=f' style="height: 150px;"'

    for x,y in options.items():
        if x=='height':
            opt+= f' style="height: {y}px;"'
        else:
            opt+= f' {x}="{y}"'
    pattern = r'^\s*:\w+:\s*\w+.*$'
    source = re.sub(pattern, '', source, flags=re.MULTILINE)
    template=f"""<logic-editor exportformat="superfence" {opt}>
    <script type="application/json">
        {source}
    </script>
    </logic-editor>"""
    return template
  
def validator(language, inputs, options, attrs, md):
    """Custom validator."""
    okay = True
    for k, v in inputs.items():
        options[k] = v
    return okay



from setuptools import setup, find_packages

setup(
    name='logic_superfence',
    version='1.2.0',
    packages=find_packages(),
    include_package_data=True,
    author='Davy Cottet',
    description='A superfence pymarkdown extension to display Logic-Circuit-Simulator',
    url='https://logic-superfence.gitlab.io',
    license='GNU General Public License v3.0',
    platforms=['Any'],
    install_requires=[
          'markdown',
          'pymdown-extensions'
      ],
    entry_points={
        'mkdocs.plugins': [
            'logic = logic_superfence:LogicBundlePlugin'
        ]
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
    ],
)


